@@ -103,9 +103,5 @@ extern const char *configfile;
 #  define HI_ZAP	BLUE	/* blue zaps! */
 #endif
 
-#ifndef EXTERN_H
-#include "extern.h"
 #endif
-
-#endif /* PCCONF_H /* */
 #endif /* MSDOS /* */
